@@ -1,5 +1,5 @@
 /*
-* Copyright (c) 2008-2016, Harald Walker (bitwalker.eu) and contributing developers 
+* Copyright (c) 2008-2018, Harald Walker (bitwalker.eu) and contributing developers 
 * All rights reserved.
 * 
 * Redistribution and use in source and binary forms, with or
@@ -90,4 +90,8 @@ public enum RenderingEngine {
 		this.name = name;
 	}
 
+        public String getName() {
+                return name;
+        }
+
 }
