@@ -59,6 +59,9 @@ public class FirefoxParameterizedTest extends
 				{
 						"Mozilla/5.0 (Macintosh; Intel Mac OS X 10.11; rv:43.0) Gecko/20100101 Firefox/43.0",
 						Browser.FIREFOX43, "43.0", OperatingSystem.MAC_OS_X },
+				{
+						"Mozilla/5.0 (Macintosh; Intel Mac OS X 10.13; rv:57.0) Gecko/20100101 Firefox/57.0",
+						Browser.FIREFOX57, "57.0", OperatingSystem.MAC_OS_X },
 				// firefox3mobile
 				{
 						"Mozilla/5.0 (X11; U; Linux armv7l; en-US; rv:1.9.2a1pre) Gecko/20091127 Firefox/3.5 Maemo Browser 1.5.6 RX-51 N900",
